@@ -1040,7 +1040,8 @@ class AppInstall(SimpleGladeApp):
         self.updateCache(filter=self.menu.filter)
         # Show window with newly installed programs
         dia = DialogComplete(self.datadir, self.window_main,
-                             to_add, to_rm, self.cache)
+                             to_add, to_rm, self.cache,
+                             self.activation_style.autoClose())
         response = dia.run()
         self.setBusy(False)
         self.activation_style.changesSuccessfulNotify()
