@@ -61,7 +61,7 @@ class AppListViewComplete(AppListView):
 
 
 class DialogComplete(SimpleGladeApp):
-    def __init__(self, datadir, parent, to_add, to_rm, cache):
+    def __init__(self, datadir, parent, to_add, to_rm, cache, auto_close=False):
         def add_apps_to_store(apps, store):
             for app in apps:
                 store.append([app.name, app, 0])
@@ -70,6 +70,7 @@ class DialogComplete(SimpleGladeApp):
                                 root="window_complete",
                                 domain="gnome-app-install")
         self.cache = cache
+        self.auto_close = auto_close
         self.store = gtk.ListStore(gobject.TYPE_STRING,
                                    gobject.TYPE_PYOBJECT,
                                    gobject.TYPE_INT)
@@ -86,6 +87,7 @@ class DialogComplete(SimpleGladeApp):
         failed_extras = []
         installed_apps = []
         installed_extras = []  
+        self.install_failures = False
         for app in to_add:
             pkg = app.pkgname
             available = cache.has_key(pkg)
@@ -111,6 +113,9 @@ class DialogComplete(SimpleGladeApp):
                     failed_apps.append(app)
                 else:
                     failed_extras.append(app)
+        # record if anything failed (for auto_close)
+        if failed_extras or failed_apps:
+                self.install_failures = True
         # Connect the signals
         self.button_complete_retry.connect("clicked",
                                            self.on_button_retry_clicked)
@@ -195,6 +200,8 @@ class DialogComplete(SimpleGladeApp):
                                                                        body))
 
     def run(self):
+        if (self.auto_close and self.install_failures == False):
+            return gtk.RESPONSE_CLOSE
         self.window_complete.show()
         gtk.main()
         return self._response
