@@ -61,6 +61,9 @@ class ActivationStyle:
         return self._menu_filter
     def preRun(self):
         return True
+    def autoClose(self):
+        " auto close on successful install/remove "
+        return False
 
 class SearchActivationStyle(ActivationStyle):
     def __init__(self, dictname, options):
@@ -235,6 +238,10 @@ class CodecSearchActivationStyle(SearchActivationStyle):
                print >>sys.stderr, _("additional codec installation failed")
                sys.exit(2)
 
+    def autoClose(self):
+        " auto close the app on successful codec installs "
+        return True
+
 class MimeSearchActivationStyle(SearchActivationStyle):
     def __init__(self, options, uri, duri):
         SearchActivationStyle.__init__(self, 'mime', options)
